﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Summerset.Isbndb.Authors
{
    /// <summary>
    /// Represents a request from the authors collection.
    /// </summary>
    public sealed class AuthorsRequest : RequestBase
    {
        #region Constructor

        /// <summary>
        /// Initializes a new instance of the AuthorsRequest.
        /// </summary>
        /// <param name="indexName">The index which will be queried with the search terms.</param>
        /// <param name="searchTerms">The search terms that will be used to query the collection.</param>
        /// <param name="additionalResultFields">Additional details to request from the API.</param>
        public AuthorsRequest(string indexName, string searchTerms, params string[] additionalResultFields)
            : base(indexName, searchTerms, additionalResultFields)
        { }

        #endregion
        #region Overridden Properties

        /// <summary>
        /// Gets the base URI for all requests against the authors collection.
        /// </summary>
        public override Uri RequestBaseUri
        {
            get { return new Uri("http://isbndb.com/api/authors.xml"); }
        }

        /// <summary>
        /// Gets all the valid indexes for this collection.
        /// </summary>
        protected override Func<string[]> GetValidIndexNames
        {
            get { return new Func<string[]>(AuthorsArgs.GetValidIndexArguments); }
        }

        /// <summary>
        /// Gets all the valid additional result fields for this collection.
        /// </summary>
        protected override Func<string[]> GetValidAdditionalResultFields
        {
            get { return new Func<string[]>(AuthorsArgs.GetValidResultArguments); }
        }

        #endregion
    }
}
