﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.ComponentModel;
using System.Diagnostics;


namespace Summerset.Isbndb.Books
{
    /// <summary>
    /// Contains data from one paginated response from the books collection.
    /// </summary>
    /// <remarks>
    /// Once this object is loaded, it's properties and the <see cref="BookElement"/> that it contains
    /// are immutable.  
    /// 
    /// NOTE:  This is the only class that actually communicates with the ISBNdb API.  All other classes base their data on the data obtained from
    /// the <see cref="BooksResponsePage"/> instances.  This is why the first page is always loaded syncronously when a BooksResponsePageCollection
    /// is initialized.
    /// </remarks>
    public class BooksResponsePage : ResponsePageBase<BookElement>
    {
        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="BooksResponsePage"/> class.
        /// </summary>
        /// <param name="pageNumber">The 1-based number of this page.</param>
        /// <param name="requestUri">The full uri including the request query string.</param>
        public BooksResponsePage(int pageNumber, Uri requestUri) 
            : base(pageNumber, requestUri)
        { }
        #endregion
        #region Overridden Properties

        /// <summary>
        /// Gets the xpath expression that will be used to retrieve the list element.  
        /// </summary>
        protected override string ListElementXpath
        {
            get { return "//BookList"; }
        }

        /// <summary>
        /// Gets the xpath expression that can be used to retrieve the individual elements.
        /// </summary>
        protected override string ElementXpath
        {
            get { return "//BookData"; }
        }
        #endregion


    }
}
