﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Summerset.Isbndb.Categories
{
    /// <summary>
    /// Represents a query that can be executed against the categories collection.
    /// </summary>
    public sealed class CategoriesRequest : RequestBase
    {
        #region Constructor

        /// <summary>
        /// Initializes a new instance of the CategoriesRequest.
        /// </summary>
        /// <param name="indexName">The index which will be queried with the search terms.</param>
        /// <param name="searchTerms">The search terms that will be used to query the collection.</param>
        /// <param name="additionalResultFields">Additional details to request from the API.</param>
        public CategoriesRequest(string indexName, string searchTerms, params string[] additionalResultFields)
            : base(indexName, searchTerms, additionalResultFields) { }

        #endregion
        #region Overridden Properties

        /// <summary>
        /// Gets the base URI for all requests against this collection.
        /// </summary>
        public override Uri RequestBaseUri
        {
            get { return new Uri("http://isbndb.com/api/categories.xml"); }
        }

        /// <summary>
        /// Gets all the valid indexes for this collection.
        /// </summary>
        protected override Func<string[]> GetValidIndexNames
        {
            get { return new Func<string[]>(CategoriesArgs.GetValidIndexArguments); }
        }

        /// <summary>
        /// Gets all the valid additional result fields for this collection.
        /// </summary>
        protected override Func<string[]> GetValidAdditionalResultFields
        {
            get { return new Func<string[]>(CategoriesArgs.GetValidResultArguments); }
        }

        #endregion
    }
}
